import request from '../../utils/request'
import apis from '../../config/api'

export default {

    namespaced: true,
    state: {
        policyList: []
    },
    mutations: {
        updateList(state, payload) {
            state.policyList = payload.records
        }
    },
    actions: {
        getPolicyList ({ commit }, payload) {
            return new Promise((resolve, reject) => {
                request({
                    ...apis.policy.list,
                    params: payload,
                }).then((data) => {
                    commit('updateList', data)
                    resolve(data)
                }).catch((err) => {
                    reject(err)
                })
            })
        },
        addPolicy ({ commit }, payload) {
            return new Promise((resolve, reject) => {
                request({
                    ...apis.policy.add,
                    data: payload,
                }).then((data) => {
                    resolve(data)
                }).catch((err) => {
                    reject(err)
                })
            })
        },
        updatePolicy ({ commit }, payload) {
            return new Promise((resolve, reject) => {
                request({
                    ...apis.policy.update,
                    urlData: { id: payload.policyId },
                    data: payload,
                }).then((data) => {
                    resolve(data)
                }).catch((err) => {
                    reject(err)
                })
            })
        },
        deletePolicy ({ commit }, payload) {
            return new Promise((resolve, reject) => {
                request({
                    ...apis.policy.delete,
                    urlData: { id: payload.policyId },
                }).then((data) => {
                    resolve(data)
                }).catch((err) => {
                    reject(err)
                })
            })
        },
        getByIdPolicy ({ commit }, payload) {
            return new Promise((resolve, reject) => {
                request({
                    ...apis.policy.getById,
                    urlData: { id: payload.policyId },
                }).then((data) => {
                    resolve(data)
                }).catch((err) => {
                    reject(err)
                })
            })
        },
    }

}